@@ -569,6 +569,7 @@ class DragonGather(TaskScheduler):
         The logging system is a task by process
         """
         # input : ids, loop, sta
+        await asyncio.sleep(.5)
         loop = asyncio.get_event_loop()
         log = kwargs.get('log')
         v = int(args[0])
@@ -584,7 +585,7 @@ class DragonGather(TaskScheduler):
         """
         body, origin, destiny = False, False, False
 
-        if not set_init_flag:
+        if not sta_init_flag:
             # para controlar que?
             control = None
             # punto de inicio a consultar
@@ -616,17 +617,17 @@ class DragonGather(TaskScheduler):
                     "PD_TO1: Tiempo fuera para conectar db source %s" % rc)
                 kwargs["origin_exception"] = "PD_TO1_00 + %s" % code
                 self.rethinkdb_origin[ids] = False
-                return [ids, ipt, v,
+                return [ipt, ids, v,
                         [di, control, (rc, rc_enu),
                          process_data]], kwargs
         """
         Iniciar objeto database destino
         """
-        if not self.rethinkdb_origin.get(ids):
+        if not self.rethinkdb_enu_origin.get(ids):
             # las dos instancias a dbs rethinkdb
             # rc: origen
             # rec_enu: destino
-            rc = self.add_sta_instance_origin(ids, loop)
+            rc_enu = self.add_sta_instance_destiny(ids, loop)
             try:
                 conn_enu = await rc_enu.async_connect()
                 await rc_enu.list_dbs()
@@ -644,12 +645,13 @@ class DragonGather(TaskScheduler):
                     "PD_TO2: Tiempo fuera para conectar db destiny %s" % rc)
                 kwargs["origin_exception"] = "PD_TO1_00 + %s" % code
                 self.rethinkdb_origin_enu[ids] = False
-                return [ids, ipt, v,
+                bprint(kwargs)
+                return [ipt, ids, v,
                         [di, control, (rc, rc_enu),
                          process_data]], kwargs
         if body or origin or destiny:
             v = 2
-            wargs = [ids, ipt, v, [di, control, (rc, rc_enu), process_data]]
+            wargs = [ipt, ids, v, [di, control, (rc, rc_enu), process_data]]
             return wargs, kwargs
         elif sta_init_flag:
             code = self.stations[ids]['code']
@@ -662,23 +664,24 @@ class DragonGather(TaskScheduler):
                                             [di, df],
                                             filter_opt,
                                             key)
-                cursor = await wait_for(future, timeout=30)
+                cursor = await shield(wait_for(future, timeout=30))
             except asyncio.TimeoutError as e:
-                log.exception("PD_TO3: Tiempo fuera para conectar db % s, al
-                              leer datos desde db" % rc)
+                log.exception(
+                    "PD_TO3: Tiempo fuera para conectar db % s, al leer datos desde db" % rc)
                 kwargs["origin_exception"] = "PD_TO3_00 + %s" % code
                 self.rethinkdb_origin[ids] = False
-                wargs = [ids, ipt, v, [
+                bprint(kwargs)
+                wargs = [ipt, ids, v, [
                     di, control, (rc, rc_enu), process_data]]
                 return wargs, kwargs
             except Exception as ex:
                 print("Exception", ex)
                 print("Error en obtención de data desde rethinkdb")
                 rc.logerror(
-                    "Error en la obtención de datos para estación %s en %s" %
-                    (code, di))
+                    "Error en la obtención de datos para estación %s en %s" % (code, di))
                 kwargs["origin_exception"] = "PD_TO4_00 + %s" % code
-                wargs = [ids, ipt, v, [
+                self.rethinkdb_origin[ids] = False
+                wargs = [ipt, ids, v, [
                     di, control, (rc, rc_enu), process_data]]
                 return wargs, kwargs
 
@@ -721,18 +724,19 @@ class DragonGather(TaskScheduler):
                         if self.dbus_geojson_queue:
                             self.dbus_geojson_queue.put(send)
                     except asyncio.TimeoutError as e:
-                        log.exception("PD_TO3: Tiempo fuera para conectar db %
-                                      s, al leer datos desde db" % rc)
+                        log.exception(
+                            "PD_TO3: Tiempo fuera para conectar db %s, al leer datos desde db" % rc)
                         kwargs["origin_exception"] = "PD_TO5_01 + %s" % code
                         self.rethinkdb_origin_enu[ids] = False
-                        wargs = [ids, ipt, v, [
+                        wargs = [ipt, ids, v, [
                             di, control, (rc, rc_enu), process_data]]
                         return wargs, kwargs
                     except Exception as ex:
                         print("WS Error al enviar %s a cola %s" %
                               (code, ex), flush=True)
                         kwargs["origin_exception"] = "PD_TO5_02 + %s" % code
-                        return [ids, ipt, v,
+                        bprint(kwargs)
+                        return [ipt, ids, v,
                                 [di, control,
                                  (rc, rc_enu),
                                  process_data]], kwargs
@@ -742,13 +746,11 @@ class DragonGather(TaskScheduler):
                     msg = "Error en estacixon %s  ----> %s" % (code, c)
                     await rc.msg_log(msg, "DEBUG")
             if cursor:
-                dt_recv = cursor[-1], get('DT_RECV')
+                dt_recv = cursor[-1].get('DT_RECV')
                 di = cursor[-1].get('DT_GEN', dt_recv)
                 control = True
-            else:
-                di = di
-            return [ids, ipt, v, [di, control, (rc, rc_enu), process_data]], kwargs
-        return [ids, ipt, v, sta], kwargs
+            return [ipt, ids, v, [di, control, (rc, rc_enu), process_data]], kwargs
+        return [ipt, ids, v, sta], kwargs
 
     async def status_gather_task(self, ids, loop, wargs_list):
         # List of stations asigned to cpu
